==> haskell-linear-1.23.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-CrM8CyzWcaA7CZqr2iVjBy
key:                  linear-1.23.2-CrM8CyzWcaA7CZqr2iVjBy
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  e5d7cbbf1da172800fb5d7c22f1ce410
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-CrM8CyzWcaA7CZqr2iVjBy
depends:
    adjunctions-4.4.3-EpJNyPLKU5W1ds1POsN27e base-4.17.2.1
    base-orphans-0.9.3-K0jSnIfYlPW34ZON03RGHV binary-0.8.9.1
    bytes-0.17.4-AZsA02sCvabAcuozdRs0bF
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-4BGER1sRuBBJLqHRISW5MJ
    ghc-prim-0.9.1 hashable-1.4.6.0-8MG0S5dfyXU6lRGLMgbs1l
    indexed-traversable-0.1.4-1hTsLhK6E4tI5A8Ow8lBff
    lens-5.3.2-2XqN7dz4nG34Xtk8WfM3fs
    random-1.2.1.3-BehtSTiFIU58dvHGLgfoiP
    reflection-2.1.9-JKI2Y7AZ70q3uWzN1l4Q1h
    semigroupoids-6.0.1-2Z3Ks6N6L6gJJh9acDP1Dt
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Iia3zhz8DVL3Efh3E6ja96
    vector-0.13.2.0-89nHvRrlFmk5zBBEvFgHzR
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.23.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.2
visibility:           public
id:                   linear-1.23.2-8wOCNes2ABiKozzZvSKPfQ
key:                  linear-1.23.2-8wOCNes2ABiKozzZvSKPfQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  7363df199f33e634a4a9f1caf2434bcd
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/linear-1.23.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.2-8wOCNes2ABiKozzZvSKPfQ
depends:
    adjunctions-4.4.3-KBS3u5mqGZkIZ8d6jpDcid base-4.17.2.1
    base-orphans-0.9.3-8pe05p4s3e22sd5AnozvzO binary-0.8.9.1
    bytes-0.17.4-8gmKyk35CutK72Z59bhR2x
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    deepseq-1.4.8.0 distributive-0.6.2.1-Hv0RNQIYamu2Xta1A0P3nz
    ghc-prim-0.9.1 hashable-1.4.6.0-AnOmtRToJbI9DS9f6Gdy0i
    indexed-traversable-0.1.4-9hXlgoaGrHXBpvZrKSRx7V
    lens-5.3.2-fiszOW9VlT8rCDJtY0rRn
    random-1.2.1.3-EWI627yJJMEDZyiJYbiRy4
    reflection-2.1.9-IOO8xxxk2jV4iMnSzugeFL
    semigroupoids-6.0.1-A5smyMIEEuhJFgyyaGAx41
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-KDi8IgRcOV5HCm7hBAqDWV
    vector-0.13.2.0-FDZBPFjQhmHDghUn2Zh3lL
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
